battle_net library

Dart wrapper client for Battle.Net API https://develop.battle.net/documentation

Classes

Asset
Represents an asset within the Mythic Keystone Affix Media Response.
AuthorizationCodeResponse
Represents the response data model for the Authorization Code flow.
BattleNet
A Dart wrapper client for the Battle.net API.
CheckTokenResponse
Represents the response data model for checking a token's validity.
ClientCredentialsResponse
Represents the response data model for the client credentials flow.
ConnectedRealmSearchData
A class that represents the data associated with a connected realm search.
ConnectedRealmSearchResponse
A class that represents the response from a connected realm search.
KeyNameIdData
Represents key, name, and ID data for a Mythic Keystone affix.
Media
Represents media information for a Mythic Keystone Affix.
MythicKeystoneAffixesIndexResponse
Represents the index response for Mythic Keystone affixes.
MythicKeystoneAffixMediaResponse
Represents the media response for a Mythic Keystone Affix.
MythicKeystoneAffixResponse
Represents a Mythic Keystone Affix response.
MythicKeystonePeriodResponse
Represents a Mythic Keystone period response.
MythicKeystonePeriodsIndexResponse
Represents the index response for Mythic Keystone periods.
Period
Represents a Mythic Keystone period.
PopulationTypeLocalised
A class representing localized population type data for a realm.
RealmLocalised
A class representing localized realm data.
ServerStatusLocalised
Represents the localized server status with its name and type.
TokenIndexResponse
Represents the response model for WoW Token index information.
UserInfoResponse
A class that represents the response received after requesting user information in an OAuth2 authentication flow.

Enums

BattleNetLocale
All available API resources provide localized strings using the locale query string parameter. Supported locales vary from region to region and align with those supported on Blizzard community sites.
BattleNetNamespace
Namespaces allow JSON documents to be published contextually in relation to a specific patch or point in time.
BattleNetRegion
API data is limited to specific regions. For example, US APIs accessed through us.battle.net only contain data from US battlegroups and realms. Locale support is limited to locations supported on Blizzard community game sites.
BattleNetScope
Scopes are used to request specific information from a site user. Applications do not require any additional scopes to use Battle.net login. Without scopes, applications can only gain access to a user's account ID and BattleTag. To get any more specific user information, an application needs to request permission from the user with scopes.
LogLevel
Defines the logging levels for the Battle.net API client.
PopulationType
Enum representing the different types of population statuses for a realm.
RealmLocale
Enum representing the different locales supported for realms.
RealmTimezone
Enum representing the different timezones for realms.
ServerStatus
Enum representing server status types: UP or DOWN.

Extensions

BattleNetLocaleExtension on BattleNetLocale
Extension on BattleNetLocale to provide the string representation of the locale.
BattleNetNamespaceExtension on BattleNetNamespace
Extension on BattleNetNamespace to provide the string representation of the namespace.
BattleNetRegionExtension on BattleNetRegion
Extension on BattleNetRegion to provide slug and name representations.
BattleNetScopeExtension on BattleNetScope
Extension on BattleNetScope to provide the string representation of the scope.

Properties

populationTypeValues → EnumValues<PopulationType>
A helper class to map population type values to and from strings.
final
realmLocaleValues → EnumValues<RealmLocale>
A mapping of string values to RealmLocale enums.
final
realmTimezoneValues → EnumValues<RealmTimezone>
A mapping of string values to RealmTimezone enums.
final
serverStatusValues → EnumValues<ServerStatus>
Holds mapping values for ServerStatus enum values and their string representations.
final