BattleNetNamespace enum

Namespaces allow JSON documents to be published contextually in relation to a specific patch or point in time.

Inheritance
Available extensions

Values

static → const BattleNetNamespace

Static namespace.

dynamic → const BattleNetNamespace

Dynamic namespace.

profile → const BattleNetNamespace

Profile namespace.

staticClassic1x → const BattleNetNamespace

Static Classic 1x namespace.

dynamicClassic1x → const BattleNetNamespace

Dynamic Classic 1x namespace.

staticClassic → const BattleNetNamespace

Static Classic namespace.

dynamicClassic → const BattleNetNamespace

Dynamic Classic namespace.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on BattleNetNamespace, provided by the BattleNetNamespaceExtension extension

Returns the string representation of the BattleNetNamespace enum value.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BattleNetNamespace>
A constant List of the values in this enum, in order of their declaration.