BattleNetRegion enum

API data is limited to specific regions. For example, US APIs accessed through us.battle.net only contain data from US battlegroups and realms. Locale support is limited to locations supported on Blizzard community game sites.

Inheritance
Available extensions

Values

us → const BattleNetRegion

North America region.

eu → const BattleNetRegion

Europe region.

kr → const BattleNetRegion

Korea region.

tw → const BattleNetRegion

Taiwan region.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on BattleNetRegion, provided by the BattleNetRegionExtension extension

Returns the full name representation of the BattleNetRegion enum value.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String

Available on BattleNetRegion, provided by the BattleNetRegionExtension extension

Returns the slug representation of the BattleNetRegion enum value.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BattleNetRegion>
A constant List of the values in this enum, in order of their declaration.