BattleNetScope enum

Scopes are used to request specific information from a site user. Applications do not require any additional scopes to use Battle.net login. Without scopes, applications can only gain access to a user's account ID and BattleTag. To get any more specific user information, an application needs to request permission from the user with scopes.

Inheritance
Available extensions

Values

wowProfile → const BattleNetScope

World of Warcraft profile scope.

sc2Profile → const BattleNetScope

StarCraft II profile scope.

d3Profile → const BattleNetScope

Diablo III profile scope.

openid → const BattleNetScope

OpenID scope.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on BattleNetScope, provided by the BattleNetScopeExtension extension

Returns the string representation of the BattleNetScope enum value.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BattleNetScope>
A constant List of the values in this enum, in order of their declaration.