ConnectedRealmSearchResponse class

A class that represents the response from a connected realm search.

This model provides pagination information and a list of connected realm search results.

Annotations
  • @immutable

Constructors

ConnectedRealmSearchResponse({required int page, required int pageSize, required int maxPageSize, required int pageCount, required List<ConnectedRealmResult> results})
Creates an instance of ConnectedRealmSearchResponse.
const
ConnectedRealmSearchResponse.fromJson(Map<String, dynamic> json)
Creates an instance of ConnectedRealmSearchResponse from a JSON map.
factory
ConnectedRealmSearchResponse.fromRawJson(String str)
Creates an instance of ConnectedRealmSearchResponse from a JSON string.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
maxPageSize int
The maximum number of results per page.
final
page int
The current page number of the search results.
final
pageCount int
The total number of pages of results.
final
pageSize int
The number of results per page.
final
results List<ConnectedRealmResult>
The list of search results for connected realms.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? page, int? pageSize, int? maxPageSize, int? pageCount, List<ConnectedRealmResult>? results}) ConnectedRealmSearchResponse
Returns a copy of this instance with the given fields replaced by new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this instance to a JSON map.
toRawJson() String
Converts this instance to a JSON string.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override