KeyNameIdData class

Represents key, name, and ID data for a Mythic Keystone affix.

Annotations
  • @immutable

Constructors

KeyNameIdData({required Key key, required String? name, required int id})
Creates an instance of KeyNameIdData.
const
KeyNameIdData.fromJson(Map<String, dynamic> json)
Creates an instance of KeyNameIdData from a JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
id int
The unique identifier of the affix.
final
key → Key
The key associated with the affix.
final
name String?
The name of the affix.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this instance to a JSON map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override