LogLevel enum

Defines the logging levels for the Battle.net API client.

These levels control the verbosity of the logs, from displaying nothing to showing full request and response bodies.

Inheritance
Available extensions

Values

NONE → const LogLevel

No logging is displayed.

BASIC → const LogLevel

Displays only URIs.

HEADERS → const LogLevel

Displays URIs and headers.

BODY → const LogLevel

Displays URIs, headers, and request/response bodies.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LogLevel>
A constant List of the values in this enum, in order of their declaration.