Media class

Represents media information for a Mythic Keystone Affix.

Annotations
  • @immutable

Constructors

Media({required Key key, required int id})
Creates an instance of Media.
const
Media.fromJson(Map<String, dynamic> json)
Creates an instance of Media from a JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
id int
The unique identifier of the media.
final
key → Key
The key associated with the media.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this instance to a JSON map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override