MythicKeystoneAffixResponse class

Represents a Mythic Keystone Affix response.

This class contains details about a specific Mythic Keystone affix, including its links, ID, name, description, and associated media.

Annotations
  • @immutable

Constructors

MythicKeystoneAffixResponse({required Links links, required int id, required String name, required String description, required Media media})
Creates an instance of MythicKeystoneAffixResponse.
const
MythicKeystoneAffixResponse.fromJson(Map<String, dynamic> json)
Creates an instance of MythicKeystoneAffixResponse from a JSON map.
factory
MythicKeystoneAffixResponse.fromRawJson(String str)
Creates an instance of MythicKeystoneAffixResponse from a raw JSON string.
factory

Properties

description String
The description of the affix.
final
hashCode int
The hash code for this object.
no setteroverride
id int
The unique identifier of the affix.
final
Links associated with the affix response.
final
media Media
Media information for the affix.
final
name String
The name of the affix.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this instance to a JSON map.
toRawJson() String
Converts this instance to a raw JSON string.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override