MythicKeystoneAffixesIndexResponse class

Represents the index response for Mythic Keystone affixes.

This class contains links and a list of Mythic Keystone affixes.

Annotations
  • @immutable

Constructors

MythicKeystoneAffixesIndexResponse({required Links links, required List<KeyNameIdData> affixes})
Creates an instance of MythicKeystoneAffixesIndexResponse.
const
MythicKeystoneAffixesIndexResponse.fromJson(Map<String, dynamic> json)
Creates an instance of MythicKeystoneAffixesIndexResponse from a JSON map.
factory
MythicKeystoneAffixesIndexResponse.fromRawJson(String str)
Creates an instance of MythicKeystoneAffixesIndexResponse from a raw JSON string.
factory

Properties

affixes List<KeyNameIdData>
A list of Mythic Keystone affixes.
final
hashCode int
The hash code for this object.
no setteroverride
Links associated with the affix index response.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this instance to a JSON map.
toRawJson() String
Converts this instance to a raw JSON string.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override