PopulationType enum

Enum representing the different types of population statuses for a realm.

Inheritance
Available extensions

Values

LOW → const PopulationType

Low population.

MEDIUM → const PopulationType

Medium population.

FULL → const PopulationType

Full population.

HIGH → const PopulationType

High population.

LOCKED → const PopulationType

Locked realm.

Recommended realm.

OFFLINE → const PopulationType

Offline realm.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PopulationType>
A constant List of the values in this enum, in order of their declaration.