RealmTimezone enum

Enum representing the different timezones for realms.

Inheritance
Available extensions

Values

EUROPE_PARIS → const RealmTimezone

Europe/Paris timezone.

ASIA_SEOUL → const RealmTimezone

Asia/Seoul timezone.

ASIA_TAIPEI → const RealmTimezone

Asia/Taipei timezone.

AMERICA_LOS_ANGELES → const RealmTimezone

America/Los_Angeles timezone.

AMERICA_CHICAGO → const RealmTimezone

America/Chicago timezone.

AMERICA_NEW_YORK → const RealmTimezone

America/New_York timezone.

AMERICA_DENVER → const RealmTimezone

America/Denver timezone.

AMERICA_SAO_PAULO → const RealmTimezone

America/Sao_Paulo timezone.

AUSTRALIA_MELBOURNE → const RealmTimezone

Australia/Melbourne timezone.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RealmTimezone>
A constant List of the values in this enum, in order of their declaration.