Asset class
Represents an asset within the Mythic Keystone Affix Media Response.
- Annotations
-
- @immutable
Constructors
Properties
- fileDataId → int
-
The file data ID of the asset.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- key → String
-
The key of the asset.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The value (URL) of the asset.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this instance to a JSON map.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override