copyWith method
Returns a copy of this instance with the given fields replaced by new values.
If a field is not provided, the existing value is retained.
Implementation
AuthorizationCodeResponse copyWith({
String? accessToken,
String? tokenType,
int? expiresIn,
List<BattleNetScope>? scope,
String? sub,
String? idToken,
}) => AuthorizationCodeResponse(
accessToken: accessToken ?? this.accessToken,
tokenType: tokenType ?? this.tokenType,
expiresIn: expiresIn ?? this.expiresIn,
scope: scope ?? this.scope,
sub: sub ?? this.sub,
idToken: idToken ?? this.idToken,
);