BattleNetLocale enum
All available API resources provide localized strings using the locale query string parameter. Supported locales vary from region to region and align with those supported on Blizzard community sites.
- Inheritance
- Available extensions
Values
- enUS → const BattleNetLocale
- esMX → const BattleNetLocale
- ptBR → const BattleNetLocale
- deDE → const BattleNetLocale
- enGB → const BattleNetLocale
- esES → const BattleNetLocale
- frFR → const BattleNetLocale
- itIT → const BattleNetLocale
- ruRU → const BattleNetLocale
- koKR → const BattleNetLocale
- zhTW → const BattleNetLocale
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on BattleNetLocale, provided by the BattleNetLocaleExtension extension
Returns the string representation of the BattleNetLocale enum value.no setter - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BattleNetLocale> - A constant List of the values in this enum, in order of their declaration.