copyWith method
Returns a copy of this instance with the given fields replaced by new values.
If a field is not provided, the existing value is retained.
Implementation
CheckTokenResponse copyWith({
String? userName,
List<BattleNetScope>? scope,
List<String>? accountAuthorities,
int? exp,
List<String>? clientAuthorities,
List<String>? authorities,
String? clientId,
}) => CheckTokenResponse(
userName: userName ?? this.userName,
scope: scope ?? this.scope,
accountAuthorities: accountAuthorities ?? this.accountAuthorities,
exp: exp ?? this.exp,
clientAuthorities: clientAuthorities ?? this.clientAuthorities,
authorities: authorities ?? this.authorities,
clientId: clientId ?? this.clientId,
);