ConnectedRealmSearchData class
A class that represents the data associated with a connected realm search.
This model encapsulates details about realms, their status, population, and queue information.
- Annotations
-
- @immutable
Constructors
-
ConnectedRealmSearchData({required List<
RealmLocalised> realms, required int id, required bool hasQueue, required ServerStatusLocalised status, required PopulationTypeLocalised population}) -
Creates an instance of ConnectedRealmSearchData.
const
-
ConnectedRealmSearchData.fromJson(Map<
String, dynamic> json) -
Creates an instance of ConnectedRealmSearchData from a JSON map.
factory
- ConnectedRealmSearchData.fromRawJson(String str)
-
Creates an instance of ConnectedRealmSearchData from a JSON string.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasQueue → bool
-
Indicates if there is a queue to enter the realm.
final
- id → int
-
The unique identifier for the connected realm.
final
- population → PopulationTypeLocalised
-
The population type of the server.
final
-
realms
→ List<
RealmLocalised> -
The list of localized realms associated with the connected realm.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → ServerStatusLocalised
-
The status of the server.
final
Methods
-
copyWith(
{List< RealmLocalised> ? realms, int? id, bool? hasQueue, ServerStatusLocalised? status, PopulationTypeLocalised? population}) → ConnectedRealmSearchData - Returns a copy of this instance with the given fields replaced by new values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this instance to a JSON map.
-
toRawJson(
) → String - Converts this instance to a JSON string.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override