MythicKeystoneAffixMediaResponse class
Represents the media response for a Mythic Keystone Affix.
This class contains links, a list of assets, and the ID of the affix.
- Annotations
-
- @immutable
Constructors
-
MythicKeystoneAffixMediaResponse({required Links links, required List<
Asset> assets, required int id}) -
Creates an instance of MythicKeystoneAffixMediaResponse.
const
-
MythicKeystoneAffixMediaResponse.fromJson(Map<
String, dynamic> json) -
Creates an instance of MythicKeystoneAffixMediaResponse from a JSON map.
factory
- MythicKeystoneAffixMediaResponse.fromRawJson(String str)
-
Creates an instance of MythicKeystoneAffixMediaResponse from a raw JSON string.
factory
Properties
-
assets
→ List<
Asset> -
A list of assets related to the affix media.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
The unique identifier of the Mythic Keystone Affix.
final
- links → Links
-
Links associated with the media response.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this instance to a JSON map.
-
toRawJson(
) → String - Converts this instance to a raw JSON string.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override