MythicKeystonePeriodsIndexResponse class
Represents the index response for Mythic Keystone periods.
This class encapsulates a list of Mythic Keystone periods and the current period.
- Annotations
-
- @immutable
Constructors
-
MythicKeystonePeriodsIndexResponse({required Links links, required List<
Period> periods, required Period currentPeriod}) -
Creates an instance of MythicKeystonePeriodsIndexResponse.
const
-
MythicKeystonePeriodsIndexResponse.fromJson(Map<
String, dynamic> json) -
Creates an instance of MythicKeystonePeriodsIndexResponse from a JSON map.
factory
- MythicKeystonePeriodsIndexResponse.fromRawJson(String str)
-
Creates an instance of MythicKeystonePeriodsIndexResponse from a JSON string.
factory
Properties
- currentPeriod → Period
-
The current Mythic Keystone period.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- links → Links
-
Links associated with the Mythic Keystone periods index response.
final
-
periods
→ List<
Period> -
A list of Mythic Keystone periods.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Links? links, List< Period> ? periods, Period? currentPeriod}) → MythicKeystonePeriodsIndexResponse - Returns a copy of this instance with the given fields replaced by new values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this instance to a JSON map.
-
toRawJson(
) → String - Converts this instance to a JSON string.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override