PopulationTypeLocalised class
A class representing localized population type data for a realm.
This model provides the localized name and the specific type of population for a connected realm.
- Annotations
-
- @immutable
Constructors
- PopulationTypeLocalised({required NameLocalised name, required PopulationType type})
-
Creates an instance of PopulationTypeLocalised.
const
-
PopulationTypeLocalised.fromJson(Map<
String, dynamic> json) -
Creates an instance of PopulationTypeLocalised from a JSON map.
factory
- PopulationTypeLocalised.fromRawJson(String str)
-
Creates an instance of PopulationTypeLocalised from a JSON string.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → NameLocalised
-
The localized name of the population type.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → PopulationType
-
The type of population.
final
Methods
-
copyWith(
{NameLocalised? name, PopulationType? type}) → PopulationTypeLocalised - Returns a copy of this instance with the given fields replaced by new values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this instance to a JSON map.
-
toRawJson(
) → String - Converts this instance to a JSON string.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override