RealmLocale enum
Enum representing the different locales supported for realms.
Values
- FR_FR → const RealmLocale
-
French (France) locale.
- DE_DE → const RealmLocale
-
German (Germany) locale.
- EN_GB → const RealmLocale
-
English (Great Britain) locale.
- EN_US → const RealmLocale
-
English (United States) locale.
- PT_PT → const RealmLocale
-
Portuguese (Portugal) locale.
- PT_BR → const RealmLocale
-
Portuguese (Brazil) locale.
- IT_IT → const RealmLocale
-
Italian (Italy) locale.
- ES_ES → const RealmLocale
-
Spanish (Spain) locale.
- ES_MX → const RealmLocale
-
Spanish (Mexico) locale.
- RU_RU → const RealmLocale
-
Russian (Russia) locale.
- KO_KR → const RealmLocale
-
Korean (Korea) locale.
- ZH_TW → const RealmLocale
-
Chinese (Taiwan) locale.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RealmLocale> - A constant List of the values in this enum, in order of their declaration.