ServerStatusLocalised class
Represents the localized server status with its name and type.
This class is immutable and represents data related to a server status, including its localized name and type (UP or DOWN).
- Annotations
-
- @immutable
Constructors
- ServerStatusLocalised({required NameLocalised name, required ServerStatus type})
-
Constructs a ServerStatusLocalised instance.
const
-
ServerStatusLocalised.fromJson(Map<
String, dynamic> json) -
Creates a ServerStatusLocalised instance from a JSON map
json.factory - ServerStatusLocalised.fromRawJson(String str)
-
Creates a ServerStatusLocalised instance from a raw JSON string
str.factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → NameLocalised
-
The localized name of the server status.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ServerStatus
-
The type of server status, either UP or DOWN.
final
Methods
-
copyWith(
{NameLocalised? name, ServerStatus? type}) → ServerStatusLocalised - Creates a copy of this ServerStatusLocalised instance with optional new values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this ServerStatusLocalised instance to a JSON map.
-
toRawJson(
) → String - Converts this ServerStatusLocalised instance to a raw JSON string representation.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override