UserInfoResponse class
A class that represents the response received after requesting user information in an OAuth2 authentication flow.
This model contains the subject identifier, unique user ID, and BattleTag.
- Annotations
-
- @immutable
Constructors
- UserInfoResponse({required String sub, required int id, required String battleTag})
-
Creates an instance of UserInfoResponse.
const
-
UserInfoResponse.fromJson(Map<
String, dynamic> json) -
Creates an instance of UserInfoResponse from a JSON map.
factory
- UserInfoResponse.fromRawJson(String str)
-
Creates an instance of UserInfoResponse from a JSON string.
factory
Properties
- battleTag → String
-
The BattleTag associated with the user.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
The unique identifier for the user.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sub → String
-
The subject (sub) identifier, representing the user.
final
Methods
-
copyWith(
{String? sub, int? id, String? battleTag}) → UserInfoResponse - Returns a copy of this instance with the given fields replaced by new values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this instance to a JSON map.
-
toRawJson(
) → String - Converts this instance to a JSON string.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override